# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: szconfig.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'szconfig.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eszconfig.proto\x12\x08szconfig\"K\n\x14\x41\x64\x64\x44\x61taSourceRequest\x12\x19\n\x11\x63onfig_definition\x18\x01 \x01(\t\x12\x18\n\x10\x64\x61ta_source_code\x18\x02 \x01(\t\"B\n\x15\x41\x64\x64\x44\x61taSourceResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\x12\x19\n\x11\x63onfig_definition\x18\x02 \x01(\t\"N\n\x17\x44\x65leteDataSourceRequest\x12\x19\n\x11\x63onfig_definition\x18\x01 \x01(\t\x12\x18\n\x10\x64\x61ta_source_code\x18\x02 \x01(\t\"E\n\x18\x44\x65leteDataSourceResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\x12\x19\n\x11\x63onfig_definition\x18\x02 \x01(\t\"2\n\x15GetDataSourcesRequest\x12\x19\n\x11\x63onfig_definition\x18\x01 \x01(\t\"(\n\x16GetDataSourcesResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"0\n\x13VerifyConfigRequest\x12\x19\n\x11\x63onfig_definition\x18\x01 \x01(\t\"&\n\x14VerifyConfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x32\xe3\x02\n\x08SzConfig\x12R\n\rAddDataSource\x12\x1e.szconfig.AddDataSourceRequest\x1a\x1f.szconfig.AddDataSourceResponse\"\x00\x12[\n\x10\x44\x65leteDataSource\x12!.szconfig.DeleteDataSourceRequest\x1a\".szconfig.DeleteDataSourceResponse\"\x00\x12U\n\x0eGetDataSources\x12\x1f.szconfig.GetDataSourcesRequest\x1a .szconfig.GetDataSourcesResponse\"\x00\x12O\n\x0cVerifyConfig\x12\x1d.szconfig.VerifyConfigRequest\x1a\x1e.szconfig.VerifyConfigResponse\"\x00\x42X\n\x14\x63om.senzing.sdk.grpcB\rSzConfigProtoZ1github.com/senzing-garage/sz-sdk-go-grpc/szconfigb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'szconfig_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.senzing.sdk.grpcB\rSzConfigProtoZ1github.com/senzing-garage/sz-sdk-go-grpc/szconfig'
  _globals['_ADDDATASOURCEREQUEST']._serialized_start=28
  _globals['_ADDDATASOURCEREQUEST']._serialized_end=103
  _globals['_ADDDATASOURCERESPONSE']._serialized_start=105
  _globals['_ADDDATASOURCERESPONSE']._serialized_end=171
  _globals['_DELETEDATASOURCEREQUEST']._serialized_start=173
  _globals['_DELETEDATASOURCEREQUEST']._serialized_end=251
  _globals['_DELETEDATASOURCERESPONSE']._serialized_start=253
  _globals['_DELETEDATASOURCERESPONSE']._serialized_end=322
  _globals['_GETDATASOURCESREQUEST']._serialized_start=324
  _globals['_GETDATASOURCESREQUEST']._serialized_end=374
  _globals['_GETDATASOURCESRESPONSE']._serialized_start=376
  _globals['_GETDATASOURCESRESPONSE']._serialized_end=416
  _globals['_VERIFYCONFIGREQUEST']._serialized_start=418
  _globals['_VERIFYCONFIGREQUEST']._serialized_end=466
  _globals['_VERIFYCONFIGRESPONSE']._serialized_start=468
  _globals['_VERIFYCONFIGRESPONSE']._serialized_end=506
  _globals['_SZCONFIG']._serialized_start=509
  _globals['_SZCONFIG']._serialized_end=864
# @@protoc_insertion_point(module_scope)



#! /usr/bin/env python3

"""
``senzing_grpc.szabstractfactory.SzAbstractFactoryGrpc`` is a `gRPC`_ implementation
of the `senzing.szabstractfactory.SzAbstractFactory`_ interface.

.. _gRPC: https://grpc.io
.. _senzing.szabstractfactory.SzAbstractFactory: https://garage.senzing.com/sz-sdk-python/senzing.html#module-senzing.szabstractfactory
"""

# pylint: disable=E1101

from types import TracebackType
from typing import Any, Type, TypedDict, Union

import grpc
from senzing import (
    SzAbstractFactory,
    SzConfigManager,
    SzDiagnostic,
    SzEngine,
    SzProduct,
)

from .szconfigmanager import SzConfigManagerGrpc
from .szdiagnostic import SzDiagnosticGrpc
from .szengine import SzEngineGrpc
from .szproduct import SzProductGrpc

# Metadata

__all__ = ["SzAbstractFactoryGrpc", "SzAbstractFactoryParametersGrpc"]
__version__ = "0.0.1"  # See https://www.python.org/dev/peps/pep-0396/
__date__ = "2025-01-10"
__updated__ = "2025-01-16"


# -----------------------------------------------------------------------------
# SzAbstractFactoryParametersGrpc class
# -----------------------------------------------------------------------------


class SzAbstractFactoryParametersGrpc(TypedDict, total=False):
    """
    SzAbstractFactoryParameters is used to create a dictionary that can be unpacked when creating an SzAbstractFactory.
    """

    grpc_channel: grpc.Channel


# -----------------------------------------------------------------------------
# SzAbstractFactoryGrpc class
# -----------------------------------------------------------------------------


class SzAbstractFactoryGrpc(SzAbstractFactory):
    """
    SzAbstractFactory module is a factory pattern for accessing Senzing over gRPC.
    """

    # -------------------------------------------------------------------------
    # Python dunder/magic methods
    # -------------------------------------------------------------------------

    def __init__(
        self,
        grpc_channel: grpc.Channel,
    ) -> None:
        """
        Constructor

        For return value of -> None, see https://peps.python.org/pep-0484/#the-meaning-of-annotations
        """
        self.channel = grpc_channel

    def __enter__(
        self,
    ) -> Any:  # TODO: Replace "Any" with "Self" once python 3.11 is lowest supported python version.
        """Context Manager method."""
        return self

    def __exit__(
        self,
        exc_type: Union[Type[BaseException], None],
        exc_val: Union[BaseException, None],
        exc_tb: Union[TracebackType, None],
    ) -> None:
        """Context Manager method."""

    # -------------------------------------------------------------------------
    # SzAbstractFactory methods
    # -------------------------------------------------------------------------

    def create_configmanager(self) -> SzConfigManager:
        return SzConfigManagerGrpc(grpc_channel=self.channel)

    def create_diagnostic(self) -> SzDiagnostic:
        return SzDiagnosticGrpc(grpc_channel=self.channel)

    def create_engine(self) -> SzEngine:
        return SzEngineGrpc(grpc_channel=self.channel)

    def create_product(self) -> SzProduct:
        return SzProductGrpc(grpc_channel=self.channel)

    def reinitialize(self, config_id: int) -> None:
        sz_diagnostic = SzDiagnosticGrpc(grpc_channel=self.channel)
        sz_diagnostic.reinitialize(config_id=config_id)  # pylint: disable=W0212

        sz_engine = SzEngineGrpc(grpc_channel=self.channel)
        sz_engine.reinitialize(config_id=config_id)  # pylint: disable=W0212



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import szconfigmanager_pb2 as szconfigmanager__pb2

GRPC_GENERATED_VERSION = '1.72.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in szconfigmanager_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SzConfigManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetConfig = channel.unary_unary(
                '/szconfigmanager.SzConfigManager/GetConfig',
                request_serializer=szconfigmanager__pb2.GetConfigRequest.SerializeToString,
                response_deserializer=szconfigmanager__pb2.GetConfigResponse.FromString,
                _registered_method=True)
        self.GetConfigs = channel.unary_unary(
                '/szconfigmanager.SzConfigManager/GetConfigs',
                request_serializer=szconfigmanager__pb2.GetConfigsRequest.SerializeToString,
                response_deserializer=szconfigmanager__pb2.GetConfigsResponse.FromString,
                _registered_method=True)
        self.GetDefaultConfigId = channel.unary_unary(
                '/szconfigmanager.SzConfigManager/GetDefaultConfigId',
                request_serializer=szconfigmanager__pb2.GetDefaultConfigIdRequest.SerializeToString,
                response_deserializer=szconfigmanager__pb2.GetDefaultConfigIdResponse.FromString,
                _registered_method=True)
        self.GetTemplateConfig = channel.unary_unary(
                '/szconfigmanager.SzConfigManager/GetTemplateConfig',
                request_serializer=szconfigmanager__pb2.GetTemplateConfigRequest.SerializeToString,
                response_deserializer=szconfigmanager__pb2.GetTemplateConfigResponse.FromString,
                _registered_method=True)
        self.RegisterConfig = channel.unary_unary(
                '/szconfigmanager.SzConfigManager/RegisterConfig',
                request_serializer=szconfigmanager__pb2.RegisterConfigRequest.SerializeToString,
                response_deserializer=szconfigmanager__pb2.RegisterConfigResponse.FromString,
                _registered_method=True)
        self.ReplaceDefaultConfigId = channel.unary_unary(
                '/szconfigmanager.SzConfigManager/ReplaceDefaultConfigId',
                request_serializer=szconfigmanager__pb2.ReplaceDefaultConfigIdRequest.SerializeToString,
                response_deserializer=szconfigmanager__pb2.ReplaceDefaultConfigIdResponse.FromString,
                _registered_method=True)
        self.SetDefaultConfig = channel.unary_unary(
                '/szconfigmanager.SzConfigManager/SetDefaultConfig',
                request_serializer=szconfigmanager__pb2.SetDefaultConfigRequest.SerializeToString,
                response_deserializer=szconfigmanager__pb2.SetDefaultConfigResponse.FromString,
                _registered_method=True)
        self.SetDefaultConfigId = channel.unary_unary(
                '/szconfigmanager.SzConfigManager/SetDefaultConfigId',
                request_serializer=szconfigmanager__pb2.SetDefaultConfigIdRequest.SerializeToString,
                response_deserializer=szconfigmanager__pb2.SetDefaultConfigIdResponse.FromString,
                _registered_method=True)


class SzConfigManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConfigs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDefaultConfigId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTemplateConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReplaceDefaultConfigId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefaultConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefaultConfigId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SzConfigManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConfig,
                    request_deserializer=szconfigmanager__pb2.GetConfigRequest.FromString,
                    response_serializer=szconfigmanager__pb2.GetConfigResponse.SerializeToString,
            ),
            'GetConfigs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConfigs,
                    request_deserializer=szconfigmanager__pb2.GetConfigsRequest.FromString,
                    response_serializer=szconfigmanager__pb2.GetConfigsResponse.SerializeToString,
            ),
            'GetDefaultConfigId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDefaultConfigId,
                    request_deserializer=szconfigmanager__pb2.GetDefaultConfigIdRequest.FromString,
                    response_serializer=szconfigmanager__pb2.GetDefaultConfigIdResponse.SerializeToString,
            ),
            'GetTemplateConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTemplateConfig,
                    request_deserializer=szconfigmanager__pb2.GetTemplateConfigRequest.FromString,
                    response_serializer=szconfigmanager__pb2.GetTemplateConfigResponse.SerializeToString,
            ),
            'RegisterConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterConfig,
                    request_deserializer=szconfigmanager__pb2.RegisterConfigRequest.FromString,
                    response_serializer=szconfigmanager__pb2.RegisterConfigResponse.SerializeToString,
            ),
            'ReplaceDefaultConfigId': grpc.unary_unary_rpc_method_handler(
                    servicer.ReplaceDefaultConfigId,
                    request_deserializer=szconfigmanager__pb2.ReplaceDefaultConfigIdRequest.FromString,
                    response_serializer=szconfigmanager__pb2.ReplaceDefaultConfigIdResponse.SerializeToString,
            ),
            'SetDefaultConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefaultConfig,
                    request_deserializer=szconfigmanager__pb2.SetDefaultConfigRequest.FromString,
                    response_serializer=szconfigmanager__pb2.SetDefaultConfigResponse.SerializeToString,
            ),
            'SetDefaultConfigId': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefaultConfigId,
                    request_deserializer=szconfigmanager__pb2.SetDefaultConfigIdRequest.FromString,
                    response_serializer=szconfigmanager__pb2.SetDefaultConfigIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'szconfigmanager.SzConfigManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('szconfigmanager.SzConfigManager', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SzConfigManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szconfigmanager.SzConfigManager/GetConfig',
            szconfigmanager__pb2.GetConfigRequest.SerializeToString,
            szconfigmanager__pb2.GetConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetConfigs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szconfigmanager.SzConfigManager/GetConfigs',
            szconfigmanager__pb2.GetConfigsRequest.SerializeToString,
            szconfigmanager__pb2.GetConfigsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDefaultConfigId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szconfigmanager.SzConfigManager/GetDefaultConfigId',
            szconfigmanager__pb2.GetDefaultConfigIdRequest.SerializeToString,
            szconfigmanager__pb2.GetDefaultConfigIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTemplateConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szconfigmanager.SzConfigManager/GetTemplateConfig',
            szconfigmanager__pb2.GetTemplateConfigRequest.SerializeToString,
            szconfigmanager__pb2.GetTemplateConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szconfigmanager.SzConfigManager/RegisterConfig',
            szconfigmanager__pb2.RegisterConfigRequest.SerializeToString,
            szconfigmanager__pb2.RegisterConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReplaceDefaultConfigId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szconfigmanager.SzConfigManager/ReplaceDefaultConfigId',
            szconfigmanager__pb2.ReplaceDefaultConfigIdRequest.SerializeToString,
            szconfigmanager__pb2.ReplaceDefaultConfigIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetDefaultConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szconfigmanager.SzConfigManager/SetDefaultConfig',
            szconfigmanager__pb2.SetDefaultConfigRequest.SerializeToString,
            szconfigmanager__pb2.SetDefaultConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetDefaultConfigId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szconfigmanager.SzConfigManager/SetDefaultConfigId',
            szconfigmanager__pb2.SetDefaultConfigIdRequest.SerializeToString,
            szconfigmanager__pb2.SetDefaultConfigIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



#! /usr/bin/env python3

"""
``senzing_grpc.szconfig.SzConfigGrpc`` is a `gRPC`_ implementation
of the `senzing.szconfig.SzConfig`_ interface.

.. _gRPC: https://grpc.io
.. _senzing.szconfig.SzConfig: https://garage.senzing.com/sz-sdk-python/senzing.html#module-senzing.szconfig
"""

# pylint: disable=E1101

from types import TracebackType
from typing import Any, Dict, Type, Union

import grpc
from senzing import SzConfig

from .pb2_grpc import szconfig_pb2, szconfig_pb2_grpc
from .szhelpers import new_exception

# Metadata

__all__ = ["SzConfigGrpc"]
__version__ = "0.0.1"  # See https://www.python.org/dev/peps/pep-0396/
__date__ = "2025-01-10"
__updated__ = "2025-01-16"

SENZING_PRODUCT_ID = (
    "5050"  # See https://github.com/senzing-garage/knowledge-base/blob/main/lists/senzing-component-ids.md
)

# -----------------------------------------------------------------------------
# SzConfigGrpc class
# -----------------------------------------------------------------------------


class SzConfigGrpc(SzConfig):
    """
    SzConfig module access library over gRPC.
    """

    # -------------------------------------------------------------------------
    # Python dunder/magic methods
    # -------------------------------------------------------------------------

    def __init__(
        self,
        grpc_channel: grpc.Channel,
    ) -> None:
        """
        Constructor

        For return value of -> None, see https://peps.python.org/pep-0484/#the-meaning-of-annotations
        """

        self.channel = grpc_channel
        self.stub = szconfig_pb2_grpc.SzConfigStub(self.channel)
        self.config_definition = ""

    def __enter__(
        self,
    ) -> Any:  # TODO: Replace "Any" with "Self" once python 3.11 is lowest supported python version.
        """Context Manager method."""
        return self

    def __exit__(
        self,
        exc_type: Union[Type[BaseException], None],
        exc_val: Union[BaseException, None],
        exc_tb: Union[TracebackType, None],
    ) -> None:
        """Context Manager method."""

    # -------------------------------------------------------------------------
    # SzConfig interface methods
    # -------------------------------------------------------------------------

    def add_data_source(
        self,
        data_source_code: str,
    ) -> str:
        try:
            request = szconfig_pb2.AddDataSourceRequest(  # type: ignore[unused-ignore]
                config_definition=self.config_definition, data_source_code=data_source_code
            )
            response = self.stub.AddDataSource(request)
            config_definition = response.config_definition
            if len(config_definition) > 0:
                self.config_definition = config_definition
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def delete_data_source(self, data_source_code: str) -> str:
        try:
            request = szconfig_pb2.DeleteDataSourceRequest(config_definition=self.config_definition, data_source_code=data_source_code)  # type: ignore[unused-ignore]
            response = self.stub.DeleteDataSource(request)
            config_definition = response.config_definition
            if len(config_definition) > 0:
                self.config_definition = config_definition
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def export(self) -> str:
        return self.config_definition

    def get_data_sources(self) -> str:
        try:
            request = szconfig_pb2.GetDataSourcesRequest(config_definition=self.config_definition)  # type: ignore[unused-ignore]
            response = self.stub.GetDataSources(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    # -------------------------------------------------------------------------
    # Non-public SzConfigCore methods
    # -------------------------------------------------------------------------

    def _destroy(self) -> None:
        """Null function in the sz-sdk-python-grpc implementation."""

    def import_config_definition(self, config_definition: str) -> None:
        """
        Set the internal JSON document.

        Args:
            config_definition (str): A Senzing configuration JSON document.
        """
        self.config_definition = config_definition

    def import_template(
        self,
    ) -> None:
        """
        Retrieves a Senzing configuration from the default template.
        The default template is the Senzing configuration JSON document file,
        g2config.json, located in the PIPELINE.RESOURCEPATH path.
        """

    def initialize(
        self,
        instance_name: str,
        settings: Union[str, Dict[Any, Any]],
        verbose_logging: int = 0,
    ) -> None:
        """Null function in the sz-sdk-python-grpc implementation."""
        _ = instance_name
        _ = settings
        _ = verbose_logging

    def verify_config_definition(self, config_definition: str) -> bool:
        """
        Determine if configuration definition is valid.

        Args:
            config_definition (str): A Senzing configuration JSON document.
        """
        request = szconfig_pb2.VerifyConfigRequest(config_definition=config_definition)  # type: ignore[unused-ignore]
        response = self.stub.VerifyConfig(request)
        return bool(response.result)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import szdiagnostic_pb2 as szdiagnostic__pb2

GRPC_GENERATED_VERSION = '1.72.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in szdiagnostic_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SzDiagnosticStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CheckDatastorePerformance = channel.unary_unary(
                '/szdiagnostic.SzDiagnostic/CheckDatastorePerformance',
                request_serializer=szdiagnostic__pb2.CheckDatastorePerformanceRequest.SerializeToString,
                response_deserializer=szdiagnostic__pb2.CheckDatastorePerformanceResponse.FromString,
                _registered_method=True)
        self.GetDatastoreInfo = channel.unary_unary(
                '/szdiagnostic.SzDiagnostic/GetDatastoreInfo',
                request_serializer=szdiagnostic__pb2.GetDatastoreInfoRequest.SerializeToString,
                response_deserializer=szdiagnostic__pb2.GetDatastoreInfoResponse.FromString,
                _registered_method=True)
        self.GetFeature = channel.unary_unary(
                '/szdiagnostic.SzDiagnostic/GetFeature',
                request_serializer=szdiagnostic__pb2.GetFeatureRequest.SerializeToString,
                response_deserializer=szdiagnostic__pb2.GetFeatureResponse.FromString,
                _registered_method=True)
        self.PurgeRepository = channel.unary_unary(
                '/szdiagnostic.SzDiagnostic/PurgeRepository',
                request_serializer=szdiagnostic__pb2.PurgeRepositoryRequest.SerializeToString,
                response_deserializer=szdiagnostic__pb2.PurgeRepositoryResponse.FromString,
                _registered_method=True)
        self.Reinitialize = channel.unary_unary(
                '/szdiagnostic.SzDiagnostic/Reinitialize',
                request_serializer=szdiagnostic__pb2.ReinitializeRequest.SerializeToString,
                response_deserializer=szdiagnostic__pb2.ReinitializeResponse.FromString,
                _registered_method=True)


class SzDiagnosticServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CheckDatastorePerformance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatastoreInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeature(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PurgeRepository(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reinitialize(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SzDiagnosticServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CheckDatastorePerformance': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckDatastorePerformance,
                    request_deserializer=szdiagnostic__pb2.CheckDatastorePerformanceRequest.FromString,
                    response_serializer=szdiagnostic__pb2.CheckDatastorePerformanceResponse.SerializeToString,
            ),
            'GetDatastoreInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatastoreInfo,
                    request_deserializer=szdiagnostic__pb2.GetDatastoreInfoRequest.FromString,
                    response_serializer=szdiagnostic__pb2.GetDatastoreInfoResponse.SerializeToString,
            ),
            'GetFeature': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeature,
                    request_deserializer=szdiagnostic__pb2.GetFeatureRequest.FromString,
                    response_serializer=szdiagnostic__pb2.GetFeatureResponse.SerializeToString,
            ),
            'PurgeRepository': grpc.unary_unary_rpc_method_handler(
                    servicer.PurgeRepository,
                    request_deserializer=szdiagnostic__pb2.PurgeRepositoryRequest.FromString,
                    response_serializer=szdiagnostic__pb2.PurgeRepositoryResponse.SerializeToString,
            ),
            'Reinitialize': grpc.unary_unary_rpc_method_handler(
                    servicer.Reinitialize,
                    request_deserializer=szdiagnostic__pb2.ReinitializeRequest.FromString,
                    response_serializer=szdiagnostic__pb2.ReinitializeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'szdiagnostic.SzDiagnostic', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('szdiagnostic.SzDiagnostic', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SzDiagnostic(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CheckDatastorePerformance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szdiagnostic.SzDiagnostic/CheckDatastorePerformance',
            szdiagnostic__pb2.CheckDatastorePerformanceRequest.SerializeToString,
            szdiagnostic__pb2.CheckDatastorePerformanceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDatastoreInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szdiagnostic.SzDiagnostic/GetDatastoreInfo',
            szdiagnostic__pb2.GetDatastoreInfoRequest.SerializeToString,
            szdiagnostic__pb2.GetDatastoreInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetFeature(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szdiagnostic.SzDiagnostic/GetFeature',
            szdiagnostic__pb2.GetFeatureRequest.SerializeToString,
            szdiagnostic__pb2.GetFeatureResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PurgeRepository(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szdiagnostic.SzDiagnostic/PurgeRepository',
            szdiagnostic__pb2.PurgeRepositoryRequest.SerializeToString,
            szdiagnostic__pb2.PurgeRepositoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Reinitialize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szdiagnostic.SzDiagnostic/Reinitialize',
            szdiagnostic__pb2.ReinitializeRequest.SerializeToString,
            szdiagnostic__pb2.ReinitializeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: szdiagnostic.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'szdiagnostic.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12szdiagnostic.proto\x12\x0cszdiagnostic\":\n CheckDatastorePerformanceRequest\x12\x16\n\x0eseconds_to_run\x18\x01 \x01(\x05\"3\n!CheckDatastorePerformanceResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x19\n\x17GetDatastoreInfoRequest\"*\n\x18GetDatastoreInfoResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\'\n\x11GetFeatureRequest\x12\x12\n\nfeature_id\x18\x01 \x01(\x03\"$\n\x12GetFeatureResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x18\n\x16PurgeRepositoryRequest\"\x19\n\x17PurgeRepositoryResponse\"(\n\x13ReinitializeRequest\x12\x11\n\tconfig_id\x18\x01 \x01(\x03\"\x16\n\x14ReinitializeResponse2\x81\x04\n\x0cSzDiagnostic\x12~\n\x19\x43heckDatastorePerformance\x12..szdiagnostic.CheckDatastorePerformanceRequest\x1a/.szdiagnostic.CheckDatastorePerformanceResponse\"\x00\x12\x63\n\x10GetDatastoreInfo\x12%.szdiagnostic.GetDatastoreInfoRequest\x1a&.szdiagnostic.GetDatastoreInfoResponse\"\x00\x12Q\n\nGetFeature\x12\x1f.szdiagnostic.GetFeatureRequest\x1a .szdiagnostic.GetFeatureResponse\"\x00\x12`\n\x0fPurgeRepository\x12$.szdiagnostic.PurgeRepositoryRequest\x1a%.szdiagnostic.PurgeRepositoryResponse\"\x00\x12W\n\x0cReinitialize\x12!.szdiagnostic.ReinitializeRequest\x1a\".szdiagnostic.ReinitializeResponse\"\x00\x42`\n\x14\x63om.senzing.sdk.grpcB\x11SzDiagnosticProtoZ5github.com/senzing-garage/sz-sdk-go-grpc/szdiagnosticb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'szdiagnostic_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.senzing.sdk.grpcB\021SzDiagnosticProtoZ5github.com/senzing-garage/sz-sdk-go-grpc/szdiagnostic'
  _globals['_CHECKDATASTOREPERFORMANCEREQUEST']._serialized_start=36
  _globals['_CHECKDATASTOREPERFORMANCEREQUEST']._serialized_end=94
  _globals['_CHECKDATASTOREPERFORMANCERESPONSE']._serialized_start=96
  _globals['_CHECKDATASTOREPERFORMANCERESPONSE']._serialized_end=147
  _globals['_GETDATASTOREINFOREQUEST']._serialized_start=149
  _globals['_GETDATASTOREINFOREQUEST']._serialized_end=174
  _globals['_GETDATASTOREINFORESPONSE']._serialized_start=176
  _globals['_GETDATASTOREINFORESPONSE']._serialized_end=218
  _globals['_GETFEATUREREQUEST']._serialized_start=220
  _globals['_GETFEATUREREQUEST']._serialized_end=259
  _globals['_GETFEATURERESPONSE']._serialized_start=261
  _globals['_GETFEATURERESPONSE']._serialized_end=297
  _globals['_PURGEREPOSITORYREQUEST']._serialized_start=299
  _globals['_PURGEREPOSITORYREQUEST']._serialized_end=323
  _globals['_PURGEREPOSITORYRESPONSE']._serialized_start=325
  _globals['_PURGEREPOSITORYRESPONSE']._serialized_end=350
  _globals['_REINITIALIZEREQUEST']._serialized_start=352
  _globals['_REINITIALIZEREQUEST']._serialized_end=392
  _globals['_REINITIALIZERESPONSE']._serialized_start=394
  _globals['_REINITIALIZERESPONSE']._serialized_end=416
  _globals['_SZDIAGNOSTIC']._serialized_start=419
  _globals['_SZDIAGNOSTIC']._serialized_end=932
# @@protoc_insertion_point(module_scope)



from .szabstractfactory import SzAbstractFactoryGrpc, SzAbstractFactoryParametersGrpc
from .szconfig import SzConfigGrpc
from .szconfigmanager import SzConfigManagerGrpc
from .szdiagnostic import SzDiagnosticGrpc
from .szengine import SzEngineGrpc
from .szproduct import SzProductGrpc

__all__ = [
    "SzAbstractFactoryGrpc",
    "SzAbstractFactoryParametersGrpc",
    "SzConfigGrpc",
    "SzConfigManagerGrpc",
    "SzDiagnosticGrpc",
    "SzEngineGrpc",
    "SzProductGrpc",
]



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import szengine_pb2 as szengine__pb2

GRPC_GENERATED_VERSION = '1.72.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in szengine_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SzEngineStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddRecord = channel.unary_unary(
                '/szengine.SzEngine/AddRecord',
                request_serializer=szengine__pb2.AddRecordRequest.SerializeToString,
                response_deserializer=szengine__pb2.AddRecordResponse.FromString,
                _registered_method=True)
        self.CloseExport = channel.unary_unary(
                '/szengine.SzEngine/CloseExport',
                request_serializer=szengine__pb2.CloseExportRequest.SerializeToString,
                response_deserializer=szengine__pb2.CloseExportResponse.FromString,
                _registered_method=True)
        self.CountRedoRecords = channel.unary_unary(
                '/szengine.SzEngine/CountRedoRecords',
                request_serializer=szengine__pb2.CountRedoRecordsRequest.SerializeToString,
                response_deserializer=szengine__pb2.CountRedoRecordsResponse.FromString,
                _registered_method=True)
        self.DeleteRecord = channel.unary_unary(
                '/szengine.SzEngine/DeleteRecord',
                request_serializer=szengine__pb2.DeleteRecordRequest.SerializeToString,
                response_deserializer=szengine__pb2.DeleteRecordResponse.FromString,
                _registered_method=True)
        self.ExportCsvEntityReport = channel.unary_unary(
                '/szengine.SzEngine/ExportCsvEntityReport',
                request_serializer=szengine__pb2.ExportCsvEntityReportRequest.SerializeToString,
                response_deserializer=szengine__pb2.ExportCsvEntityReportResponse.FromString,
                _registered_method=True)
        self.ExportJsonEntityReport = channel.unary_unary(
                '/szengine.SzEngine/ExportJsonEntityReport',
                request_serializer=szengine__pb2.ExportJsonEntityReportRequest.SerializeToString,
                response_deserializer=szengine__pb2.ExportJsonEntityReportResponse.FromString,
                _registered_method=True)
        self.FetchNext = channel.unary_unary(
                '/szengine.SzEngine/FetchNext',
                request_serializer=szengine__pb2.FetchNextRequest.SerializeToString,
                response_deserializer=szengine__pb2.FetchNextResponse.FromString,
                _registered_method=True)
        self.FindInterestingEntitiesByEntityId = channel.unary_unary(
                '/szengine.SzEngine/FindInterestingEntitiesByEntityId',
                request_serializer=szengine__pb2.FindInterestingEntitiesByEntityIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.FindInterestingEntitiesByEntityIdResponse.FromString,
                _registered_method=True)
        self.FindInterestingEntitiesByRecordId = channel.unary_unary(
                '/szengine.SzEngine/FindInterestingEntitiesByRecordId',
                request_serializer=szengine__pb2.FindInterestingEntitiesByRecordIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.FindInterestingEntitiesByRecordIdResponse.FromString,
                _registered_method=True)
        self.FindNetworkByEntityId = channel.unary_unary(
                '/szengine.SzEngine/FindNetworkByEntityId',
                request_serializer=szengine__pb2.FindNetworkByEntityIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.FindNetworkByEntityIdResponse.FromString,
                _registered_method=True)
        self.FindNetworkByRecordId = channel.unary_unary(
                '/szengine.SzEngine/FindNetworkByRecordId',
                request_serializer=szengine__pb2.FindNetworkByRecordIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.FindNetworkByRecordIdResponse.FromString,
                _registered_method=True)
        self.FindPathByEntityId = channel.unary_unary(
                '/szengine.SzEngine/FindPathByEntityId',
                request_serializer=szengine__pb2.FindPathByEntityIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.FindPathByEntityIdResponse.FromString,
                _registered_method=True)
        self.FindPathByRecordId = channel.unary_unary(
                '/szengine.SzEngine/FindPathByRecordId',
                request_serializer=szengine__pb2.FindPathByRecordIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.FindPathByRecordIdResponse.FromString,
                _registered_method=True)
        self.GetActiveConfigId = channel.unary_unary(
                '/szengine.SzEngine/GetActiveConfigId',
                request_serializer=szengine__pb2.GetActiveConfigIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.GetActiveConfigIdResponse.FromString,
                _registered_method=True)
        self.GetEntityByEntityId = channel.unary_unary(
                '/szengine.SzEngine/GetEntityByEntityId',
                request_serializer=szengine__pb2.GetEntityByEntityIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.GetEntityByEntityIdResponse.FromString,
                _registered_method=True)
        self.GetEntityByRecordId = channel.unary_unary(
                '/szengine.SzEngine/GetEntityByRecordId',
                request_serializer=szengine__pb2.GetEntityByRecordIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.GetEntityByRecordIdResponse.FromString,
                _registered_method=True)
        self.GetRecord = channel.unary_unary(
                '/szengine.SzEngine/GetRecord',
                request_serializer=szengine__pb2.GetRecordRequest.SerializeToString,
                response_deserializer=szengine__pb2.GetRecordResponse.FromString,
                _registered_method=True)
        self.GetRedoRecord = channel.unary_unary(
                '/szengine.SzEngine/GetRedoRecord',
                request_serializer=szengine__pb2.GetRedoRecordRequest.SerializeToString,
                response_deserializer=szengine__pb2.GetRedoRecordResponse.FromString,
                _registered_method=True)
        self.GetStats = channel.unary_unary(
                '/szengine.SzEngine/GetStats',
                request_serializer=szengine__pb2.GetStatsRequest.SerializeToString,
                response_deserializer=szengine__pb2.GetStatsResponse.FromString,
                _registered_method=True)
        self.GetVirtualEntityByRecordId = channel.unary_unary(
                '/szengine.SzEngine/GetVirtualEntityByRecordId',
                request_serializer=szengine__pb2.GetVirtualEntityByRecordIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.GetVirtualEntityByRecordIdResponse.FromString,
                _registered_method=True)
        self.HowEntityByEntityId = channel.unary_unary(
                '/szengine.SzEngine/HowEntityByEntityId',
                request_serializer=szengine__pb2.HowEntityByEntityIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.HowEntityByEntityIdResponse.FromString,
                _registered_method=True)
        self.PreprocessRecord = channel.unary_unary(
                '/szengine.SzEngine/PreprocessRecord',
                request_serializer=szengine__pb2.PreprocessRecordRequest.SerializeToString,
                response_deserializer=szengine__pb2.PreprocessRecordResponse.FromString,
                _registered_method=True)
        self.PrimeEngine = channel.unary_unary(
                '/szengine.SzEngine/PrimeEngine',
                request_serializer=szengine__pb2.PrimeEngineRequest.SerializeToString,
                response_deserializer=szengine__pb2.PrimeEngineResponse.FromString,
                _registered_method=True)
        self.ProcessRedoRecord = channel.unary_unary(
                '/szengine.SzEngine/ProcessRedoRecord',
                request_serializer=szengine__pb2.ProcessRedoRecordRequest.SerializeToString,
                response_deserializer=szengine__pb2.ProcessRedoRecordResponse.FromString,
                _registered_method=True)
        self.ReevaluateEntity = channel.unary_unary(
                '/szengine.SzEngine/ReevaluateEntity',
                request_serializer=szengine__pb2.ReevaluateEntityRequest.SerializeToString,
                response_deserializer=szengine__pb2.ReevaluateEntityResponse.FromString,
                _registered_method=True)
        self.ReevaluateRecord = channel.unary_unary(
                '/szengine.SzEngine/ReevaluateRecord',
                request_serializer=szengine__pb2.ReevaluateRecordRequest.SerializeToString,
                response_deserializer=szengine__pb2.ReevaluateRecordResponse.FromString,
                _registered_method=True)
        self.Reinitialize = channel.unary_unary(
                '/szengine.SzEngine/Reinitialize',
                request_serializer=szengine__pb2.ReinitializeRequest.SerializeToString,
                response_deserializer=szengine__pb2.ReinitializeResponse.FromString,
                _registered_method=True)
        self.SearchByAttributes = channel.unary_unary(
                '/szengine.SzEngine/SearchByAttributes',
                request_serializer=szengine__pb2.SearchByAttributesRequest.SerializeToString,
                response_deserializer=szengine__pb2.SearchByAttributesResponse.FromString,
                _registered_method=True)
        self.StreamExportCsvEntityReport = channel.unary_stream(
                '/szengine.SzEngine/StreamExportCsvEntityReport',
                request_serializer=szengine__pb2.StreamExportCsvEntityReportRequest.SerializeToString,
                response_deserializer=szengine__pb2.StreamExportCsvEntityReportResponse.FromString,
                _registered_method=True)
        self.StreamExportJsonEntityReport = channel.unary_stream(
                '/szengine.SzEngine/StreamExportJsonEntityReport',
                request_serializer=szengine__pb2.StreamExportJsonEntityReportRequest.SerializeToString,
                response_deserializer=szengine__pb2.StreamExportJsonEntityReportResponse.FromString,
                _registered_method=True)
        self.WhyEntities = channel.unary_unary(
                '/szengine.SzEngine/WhyEntities',
                request_serializer=szengine__pb2.WhyEntitiesRequest.SerializeToString,
                response_deserializer=szengine__pb2.WhyEntitiesResponse.FromString,
                _registered_method=True)
        self.WhyRecordInEntity = channel.unary_unary(
                '/szengine.SzEngine/WhyRecordInEntity',
                request_serializer=szengine__pb2.WhyRecordInEntityRequest.SerializeToString,
                response_deserializer=szengine__pb2.WhyRecordInEntityResponse.FromString,
                _registered_method=True)
        self.WhyRecords = channel.unary_unary(
                '/szengine.SzEngine/WhyRecords',
                request_serializer=szengine__pb2.WhyRecordsRequest.SerializeToString,
                response_deserializer=szengine__pb2.WhyRecordsResponse.FromString,
                _registered_method=True)
        self.WhySearch = channel.unary_unary(
                '/szengine.SzEngine/WhySearch',
                request_serializer=szengine__pb2.WhySearchRequest.SerializeToString,
                response_deserializer=szengine__pb2.WhySearchResponse.FromString,
                _registered_method=True)


class SzEngineServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AddRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloseExport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CountRedoRecords(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportCsvEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportJsonEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FetchNext(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindInterestingEntitiesByEntityId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindInterestingEntitiesByRecordId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindNetworkByEntityId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindNetworkByRecordId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindPathByEntityId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindPathByRecordId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActiveConfigId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEntityByEntityId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEntityByRecordId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRedoRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVirtualEntityByRecordId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HowEntityByEntityId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PreprocessRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PrimeEngine(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProcessRedoRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReevaluateEntity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReevaluateRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reinitialize(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchByAttributes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamExportCsvEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamExportJsonEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WhyEntities(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WhyRecordInEntity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WhyRecords(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WhySearch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SzEngineServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.AddRecord,
                    request_deserializer=szengine__pb2.AddRecordRequest.FromString,
                    response_serializer=szengine__pb2.AddRecordResponse.SerializeToString,
            ),
            'CloseExport': grpc.unary_unary_rpc_method_handler(
                    servicer.CloseExport,
                    request_deserializer=szengine__pb2.CloseExportRequest.FromString,
                    response_serializer=szengine__pb2.CloseExportResponse.SerializeToString,
            ),
            'CountRedoRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.CountRedoRecords,
                    request_deserializer=szengine__pb2.CountRedoRecordsRequest.FromString,
                    response_serializer=szengine__pb2.CountRedoRecordsResponse.SerializeToString,
            ),
            'DeleteRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRecord,
                    request_deserializer=szengine__pb2.DeleteRecordRequest.FromString,
                    response_serializer=szengine__pb2.DeleteRecordResponse.SerializeToString,
            ),
            'ExportCsvEntityReport': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportCsvEntityReport,
                    request_deserializer=szengine__pb2.ExportCsvEntityReportRequest.FromString,
                    response_serializer=szengine__pb2.ExportCsvEntityReportResponse.SerializeToString,
            ),
            'ExportJsonEntityReport': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportJsonEntityReport,
                    request_deserializer=szengine__pb2.ExportJsonEntityReportRequest.FromString,
                    response_serializer=szengine__pb2.ExportJsonEntityReportResponse.SerializeToString,
            ),
            'FetchNext': grpc.unary_unary_rpc_method_handler(
                    servicer.FetchNext,
                    request_deserializer=szengine__pb2.FetchNextRequest.FromString,
                    response_serializer=szengine__pb2.FetchNextResponse.SerializeToString,
            ),
            'FindInterestingEntitiesByEntityId': grpc.unary_unary_rpc_method_handler(
                    servicer.FindInterestingEntitiesByEntityId,
                    request_deserializer=szengine__pb2.FindInterestingEntitiesByEntityIdRequest.FromString,
                    response_serializer=szengine__pb2.FindInterestingEntitiesByEntityIdResponse.SerializeToString,
            ),
            'FindInterestingEntitiesByRecordId': grpc.unary_unary_rpc_method_handler(
                    servicer.FindInterestingEntitiesByRecordId,
                    request_deserializer=szengine__pb2.FindInterestingEntitiesByRecordIdRequest.FromString,
                    response_serializer=szengine__pb2.FindInterestingEntitiesByRecordIdResponse.SerializeToString,
            ),
            'FindNetworkByEntityId': grpc.unary_unary_rpc_method_handler(
                    servicer.FindNetworkByEntityId,
                    request_deserializer=szengine__pb2.FindNetworkByEntityIdRequest.FromString,
                    response_serializer=szengine__pb2.FindNetworkByEntityIdResponse.SerializeToString,
            ),
            'FindNetworkByRecordId': grpc.unary_unary_rpc_method_handler(
                    servicer.FindNetworkByRecordId,
                    request_deserializer=szengine__pb2.FindNetworkByRecordIdRequest.FromString,
                    response_serializer=szengine__pb2.FindNetworkByRecordIdResponse.SerializeToString,
            ),
            'FindPathByEntityId': grpc.unary_unary_rpc_method_handler(
                    servicer.FindPathByEntityId,
                    request_deserializer=szengine__pb2.FindPathByEntityIdRequest.FromString,
                    response_serializer=szengine__pb2.FindPathByEntityIdResponse.SerializeToString,
            ),
            'FindPathByRecordId': grpc.unary_unary_rpc_method_handler(
                    servicer.FindPathByRecordId,
                    request_deserializer=szengine__pb2.FindPathByRecordIdRequest.FromString,
                    response_serializer=szengine__pb2.FindPathByRecordIdResponse.SerializeToString,
            ),
            'GetActiveConfigId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActiveConfigId,
                    request_deserializer=szengine__pb2.GetActiveConfigIdRequest.FromString,
                    response_serializer=szengine__pb2.GetActiveConfigIdResponse.SerializeToString,
            ),
            'GetEntityByEntityId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEntityByEntityId,
                    request_deserializer=szengine__pb2.GetEntityByEntityIdRequest.FromString,
                    response_serializer=szengine__pb2.GetEntityByEntityIdResponse.SerializeToString,
            ),
            'GetEntityByRecordId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEntityByRecordId,
                    request_deserializer=szengine__pb2.GetEntityByRecordIdRequest.FromString,
                    response_serializer=szengine__pb2.GetEntityByRecordIdResponse.SerializeToString,
            ),
            'GetRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRecord,
                    request_deserializer=szengine__pb2.GetRecordRequest.FromString,
                    response_serializer=szengine__pb2.GetRecordResponse.SerializeToString,
            ),
            'GetRedoRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRedoRecord,
                    request_deserializer=szengine__pb2.GetRedoRecordRequest.FromString,
                    response_serializer=szengine__pb2.GetRedoRecordResponse.SerializeToString,
            ),
            'GetStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStats,
                    request_deserializer=szengine__pb2.GetStatsRequest.FromString,
                    response_serializer=szengine__pb2.GetStatsResponse.SerializeToString,
            ),
            'GetVirtualEntityByRecordId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVirtualEntityByRecordId,
                    request_deserializer=szengine__pb2.GetVirtualEntityByRecordIdRequest.FromString,
                    response_serializer=szengine__pb2.GetVirtualEntityByRecordIdResponse.SerializeToString,
            ),
            'HowEntityByEntityId': grpc.unary_unary_rpc_method_handler(
                    servicer.HowEntityByEntityId,
                    request_deserializer=szengine__pb2.HowEntityByEntityIdRequest.FromString,
                    response_serializer=szengine__pb2.HowEntityByEntityIdResponse.SerializeToString,
            ),
            'PreprocessRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.PreprocessRecord,
                    request_deserializer=szengine__pb2.PreprocessRecordRequest.FromString,
                    response_serializer=szengine__pb2.PreprocessRecordResponse.SerializeToString,
            ),
            'PrimeEngine': grpc.unary_unary_rpc_method_handler(
                    servicer.PrimeEngine,
                    request_deserializer=szengine__pb2.PrimeEngineRequest.FromString,
                    response_serializer=szengine__pb2.PrimeEngineResponse.SerializeToString,
            ),
            'ProcessRedoRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.ProcessRedoRecord,
                    request_deserializer=szengine__pb2.ProcessRedoRecordRequest.FromString,
                    response_serializer=szengine__pb2.ProcessRedoRecordResponse.SerializeToString,
            ),
            'ReevaluateEntity': grpc.unary_unary_rpc_method_handler(
                    servicer.ReevaluateEntity,
                    request_deserializer=szengine__pb2.ReevaluateEntityRequest.FromString,
                    response_serializer=szengine__pb2.ReevaluateEntityResponse.SerializeToString,
            ),
            'ReevaluateRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.ReevaluateRecord,
                    request_deserializer=szengine__pb2.ReevaluateRecordRequest.FromString,
                    response_serializer=szengine__pb2.ReevaluateRecordResponse.SerializeToString,
            ),
            'Reinitialize': grpc.unary_unary_rpc_method_handler(
                    servicer.Reinitialize,
                    request_deserializer=szengine__pb2.ReinitializeRequest.FromString,
                    response_serializer=szengine__pb2.ReinitializeResponse.SerializeToString,
            ),
            'SearchByAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchByAttributes,
                    request_deserializer=szengine__pb2.SearchByAttributesRequest.FromString,
                    response_serializer=szengine__pb2.SearchByAttributesResponse.SerializeToString,
            ),
            'StreamExportCsvEntityReport': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamExportCsvEntityReport,
                    request_deserializer=szengine__pb2.StreamExportCsvEntityReportRequest.FromString,
                    response_serializer=szengine__pb2.StreamExportCsvEntityReportResponse.SerializeToString,
            ),
            'StreamExportJsonEntityReport': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamExportJsonEntityReport,
                    request_deserializer=szengine__pb2.StreamExportJsonEntityReportRequest.FromString,
                    response_serializer=szengine__pb2.StreamExportJsonEntityReportResponse.SerializeToString,
            ),
            'WhyEntities': grpc.unary_unary_rpc_method_handler(
                    servicer.WhyEntities,
                    request_deserializer=szengine__pb2.WhyEntitiesRequest.FromString,
                    response_serializer=szengine__pb2.WhyEntitiesResponse.SerializeToString,
            ),
            'WhyRecordInEntity': grpc.unary_unary_rpc_method_handler(
                    servicer.WhyRecordInEntity,
                    request_deserializer=szengine__pb2.WhyRecordInEntityRequest.FromString,
                    response_serializer=szengine__pb2.WhyRecordInEntityResponse.SerializeToString,
            ),
            'WhyRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.WhyRecords,
                    request_deserializer=szengine__pb2.WhyRecordsRequest.FromString,
                    response_serializer=szengine__pb2.WhyRecordsResponse.SerializeToString,
            ),
            'WhySearch': grpc.unary_unary_rpc_method_handler(
                    servicer.WhySearch,
                    request_deserializer=szengine__pb2.WhySearchRequest.FromString,
                    response_serializer=szengine__pb2.WhySearchResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'szengine.SzEngine', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('szengine.SzEngine', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SzEngine(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AddRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/AddRecord',
            szengine__pb2.AddRecordRequest.SerializeToString,
            szengine__pb2.AddRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CloseExport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/CloseExport',
            szengine__pb2.CloseExportRequest.SerializeToString,
            szengine__pb2.CloseExportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CountRedoRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/CountRedoRecords',
            szengine__pb2.CountRedoRecordsRequest.SerializeToString,
            szengine__pb2.CountRedoRecordsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/DeleteRecord',
            szengine__pb2.DeleteRecordRequest.SerializeToString,
            szengine__pb2.DeleteRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExportCsvEntityReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/ExportCsvEntityReport',
            szengine__pb2.ExportCsvEntityReportRequest.SerializeToString,
            szengine__pb2.ExportCsvEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExportJsonEntityReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/ExportJsonEntityReport',
            szengine__pb2.ExportJsonEntityReportRequest.SerializeToString,
            szengine__pb2.ExportJsonEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FetchNext(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/FetchNext',
            szengine__pb2.FetchNextRequest.SerializeToString,
            szengine__pb2.FetchNextResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindInterestingEntitiesByEntityId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/FindInterestingEntitiesByEntityId',
            szengine__pb2.FindInterestingEntitiesByEntityIdRequest.SerializeToString,
            szengine__pb2.FindInterestingEntitiesByEntityIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindInterestingEntitiesByRecordId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/FindInterestingEntitiesByRecordId',
            szengine__pb2.FindInterestingEntitiesByRecordIdRequest.SerializeToString,
            szengine__pb2.FindInterestingEntitiesByRecordIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindNetworkByEntityId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/FindNetworkByEntityId',
            szengine__pb2.FindNetworkByEntityIdRequest.SerializeToString,
            szengine__pb2.FindNetworkByEntityIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindNetworkByRecordId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/FindNetworkByRecordId',
            szengine__pb2.FindNetworkByRecordIdRequest.SerializeToString,
            szengine__pb2.FindNetworkByRecordIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindPathByEntityId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/FindPathByEntityId',
            szengine__pb2.FindPathByEntityIdRequest.SerializeToString,
            szengine__pb2.FindPathByEntityIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindPathByRecordId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/FindPathByRecordId',
            szengine__pb2.FindPathByRecordIdRequest.SerializeToString,
            szengine__pb2.FindPathByRecordIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetActiveConfigId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/GetActiveConfigId',
            szengine__pb2.GetActiveConfigIdRequest.SerializeToString,
            szengine__pb2.GetActiveConfigIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetEntityByEntityId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/GetEntityByEntityId',
            szengine__pb2.GetEntityByEntityIdRequest.SerializeToString,
            szengine__pb2.GetEntityByEntityIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetEntityByRecordId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/GetEntityByRecordId',
            szengine__pb2.GetEntityByRecordIdRequest.SerializeToString,
            szengine__pb2.GetEntityByRecordIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/GetRecord',
            szengine__pb2.GetRecordRequest.SerializeToString,
            szengine__pb2.GetRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetRedoRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/GetRedoRecord',
            szengine__pb2.GetRedoRecordRequest.SerializeToString,
            szengine__pb2.GetRedoRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/GetStats',
            szengine__pb2.GetStatsRequest.SerializeToString,
            szengine__pb2.GetStatsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetVirtualEntityByRecordId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/GetVirtualEntityByRecordId',
            szengine__pb2.GetVirtualEntityByRecordIdRequest.SerializeToString,
            szengine__pb2.GetVirtualEntityByRecordIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HowEntityByEntityId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/HowEntityByEntityId',
            szengine__pb2.HowEntityByEntityIdRequest.SerializeToString,
            szengine__pb2.HowEntityByEntityIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PreprocessRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/PreprocessRecord',
            szengine__pb2.PreprocessRecordRequest.SerializeToString,
            szengine__pb2.PreprocessRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PrimeEngine(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/PrimeEngine',
            szengine__pb2.PrimeEngineRequest.SerializeToString,
            szengine__pb2.PrimeEngineResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ProcessRedoRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/ProcessRedoRecord',
            szengine__pb2.ProcessRedoRecordRequest.SerializeToString,
            szengine__pb2.ProcessRedoRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReevaluateEntity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/ReevaluateEntity',
            szengine__pb2.ReevaluateEntityRequest.SerializeToString,
            szengine__pb2.ReevaluateEntityResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReevaluateRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/ReevaluateRecord',
            szengine__pb2.ReevaluateRecordRequest.SerializeToString,
            szengine__pb2.ReevaluateRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Reinitialize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/Reinitialize',
            szengine__pb2.ReinitializeRequest.SerializeToString,
            szengine__pb2.ReinitializeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SearchByAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/SearchByAttributes',
            szengine__pb2.SearchByAttributesRequest.SerializeToString,
            szengine__pb2.SearchByAttributesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamExportCsvEntityReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/szengine.SzEngine/StreamExportCsvEntityReport',
            szengine__pb2.StreamExportCsvEntityReportRequest.SerializeToString,
            szengine__pb2.StreamExportCsvEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamExportJsonEntityReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/szengine.SzEngine/StreamExportJsonEntityReport',
            szengine__pb2.StreamExportJsonEntityReportRequest.SerializeToString,
            szengine__pb2.StreamExportJsonEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WhyEntities(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/WhyEntities',
            szengine__pb2.WhyEntitiesRequest.SerializeToString,
            szengine__pb2.WhyEntitiesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WhyRecordInEntity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/WhyRecordInEntity',
            szengine__pb2.WhyRecordInEntityRequest.SerializeToString,
            szengine__pb2.WhyRecordInEntityResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WhyRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/WhyRecords',
            szengine__pb2.WhyRecordsRequest.SerializeToString,
            szengine__pb2.WhyRecordsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WhySearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/WhySearch',
            szengine__pb2.WhySearchRequest.SerializeToString,
            szengine__pb2.WhySearchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
